<!--
 * @Author: GT<caogtaa@gmail.com>
 * @Date: 2021-05-07 12:07:31
 * @LastEditors: GT<caogtaa@gmail.com>
 * @LastEditTime: 2021-05-07 12:08:00
-->
Dilate texture with low alpha pixel to prevent "black edge" when rendered by GL